package com.kexun.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.kexun.entity.ReportFileEntity;
import com.kexun.entity.ReportInfo;
import com.kexun.service.ReportFileService;
import com.kexun.utils.DateUtils;
import org.apache.commons.io.IOUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Date;

/**
 * Description: 文件处理实现类，包括文件的读取、写入
 *
 * @author lgs
 * @date 2023/12/22
 */
@Service
public class FileServiceImpl {

    @Autowired
    ReportFileService reportFileService;
    /**
     * xml文件来源路径
     */
    @Value("${report.file.xmlSourcePath}")
    private String xmlSourcePath;
    /**
     * 解析出来的json文件
     */
    @Value("${report.file.jsonTargetPath}")
    private String jsonTargetPath;
    /**
     * 解析出来的json文件
     */
    @Value("${report.file.xmlTargetPath}")
    private String xmlTargetPath;

    /**
     * 上传文件
     *
     * @param context
     * @param filename
     * @param path
     */
    private void writeFile(String context, String filename, String path) {
        try {
            IOUtils.write(context, new FileOutputStream(path + filename), "UTF-8");
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    /**
     * 保存xml文件和json文件
     *
     * @param reportInfo
     * @param xmlContext
     * @param jsonContext
     * @param fileName
     */
    public void saveAndWriteFile(ReportInfo reportInfo, String xmlContext, String jsonContext, String fileName) {
        //根据HeadInfId查询是否存在
        ReportFileEntity reportFileEntity = new ReportFileEntity();
        if (reportInfo.getHeadInfId() != null) {
            QueryWrapper<ReportFileEntity> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("head_inf_id", reportInfo.getHeadInfId());
            ReportFileEntity reportFileEntityResult = reportFileService.getOne(queryWrapper);
            if (reportFileEntityResult != null) {
                reportFileEntity.setId(reportFileEntityResult.getId());
            }
        }
        reportFileEntity.setHeadInfId(reportInfo.getHeadInfId());
        reportFileEntity.setRptNo(reportInfo.getRptNo());
        reportFileEntity.setBusinessId(reportInfo.getBusinessId());
        reportFileEntity.setBusinessNum(reportInfo.getBusinessNum());
        String dateName = DateUtils.format(new Date(), DateUtils.YYYYMMDD);
        reportFileEntity.setFileNameXml(dateName + File.separator + fileName + ".xml");
        reportFileEntity.setFileNameTxt(dateName + File.separator + fileName + ".txt");
        //保存文件信息表
        reportFileService.saveOrUpdate(reportFileEntity);
        //上传文件到服务器的目录
        //xml文件
        xmlTargetPath = xmlTargetPath + File.separator + dateName + File.separator;
        File file = new File(xmlTargetPath);
        if (!file.exists()) {
            file.mkdirs();
        }
        jsonTargetPath = jsonTargetPath + File.separator + dateName + File.separator;
        File targetPathFile = new File(jsonTargetPath);
        if (!targetPathFile.exists()) {
            targetPathFile.mkdirs();
        }
        writeFile(xmlContext, fileName + ".xml", xmlTargetPath);
        //json文件
        writeFile(jsonContext, fileName + ".txt", jsonTargetPath);
    }


}
